import { Component } from "@angular/core";
import { NgbModal } from "@ng-bootstrap/ng-bootstrap";
import { ControlSchedulerComponent } from "../control-scheduler/control-scheduler.component";
import { ActivatedRoute } from "@angular/router";
import { DeviceService } from "../../service/device.service";
import Swal from "sweetalert2";
@Component({
  selector: "app-scheduler-list",
  templateUrl: "./scheduler-list.component.html",
  styleUrls: ["./scheduler-list.component.css"],
})
export class SchedulerListComponent {
  public breadcrumb: any;
  listScheduler: any;
  deviceId: any;
  deviceName: any;
  hasSelected: boolean = false;
  schedules = [
    {
      id: 1,
      title: "Lampu Depan ON",
      time: "08:55",
    },
    {
      id: 2,
      title: "Lampu Depan OFF",
      time: "09:50",
    },
  ];

  constructor(
    private modalService: NgbModal,
    private route: ActivatedRoute,
    private deviceService: DeviceService
  ) {}

  ngOnInit(): void {
    this.route.params.subscribe((params) => {
      const id = params["id"];
      this.deviceId = id;
      if (id) {
        this.dataListScheduler(id);
        this.dataDevice(id);
      }
    });
    this.breadcrumb = {
      mainlabel: "Scheduler List",
      linkBack: "/device/control-device",
      isLinkBack: true,
      links: [
        {
          name: "Home",
          isLink: false,
          link: "/dashboard/sales",
        },
        {
          name: "Control Device",
          isLink: false,
        },
        {
          name: "Scheduler List",
          isLink: false,
        },
      ],
    };
  }

  dataListScheduler(id) {
    this.deviceService.getDeviceScheduler(id).subscribe((data) => {
      this.listScheduler = data.results;
      console.log(this.listScheduler);
      
    });
  }

  dataDevice(id) {
    this.deviceService.getDeviceByid(id).subscribe((data) => {
      this.deviceName = data.data.name
    });
  }

  switchChanged(e, item) {
    const data = {
      id: item.id,
      active: e,
    };
    this.deviceService.putDeviceSchedulerActive(data, item.id).subscribe((res) => {
      this.dataListScheduler(this.deviceId);
    });
  }

  addSchedulerItem() {
    const modalRef = this.modalService.open(ControlSchedulerComponent, {
      size: "md",
      backdrop: "static",
      keyboard: false,
      centered: true,
    });

    modalRef.componentInstance.deviceId = this.deviceId;
    modalRef.componentInstance.mode = "add";
    modalRef.result.then(
      (result) => {
        if (result) {
          this.deviceService.postDeviceScheduler(result).subscribe((res) => {
            this.dataListScheduler(this.deviceId);
          });
        }
      },
      (reason) => {
        console.log(`Dismissed: ${reason}`);
      }
    );
    // Handle edit action
  }

  editSchedule(data) {
    const modalRef = this.modalService.open(ControlSchedulerComponent, {
      size: "md",
      backdrop: "static",
      keyboard: false,
      centered: true,
    });

    modalRef.componentInstance.deviceId = this.deviceId;
    modalRef.componentInstance.data = data;
    modalRef.componentInstance.mode = "edit";
    modalRef.result.then(
      (result) => {
        if (result) {
          this.deviceService
            .putDeviceScheduler(result, data.id)
            .subscribe((res) => {
              this.dataListScheduler(this.deviceId);
            });
        }
      },
      (reason) => {
        console.log(`Dismissed: ${reason}`);
      }
    );
  }

  checkSelected() {
    this.hasSelected = this.listScheduler.some((schedule) => schedule.selected);
  }

  deleteSelectedSchedules() {
    const selectedSchedules = this.listScheduler.filter(
      (schedule) => schedule.selected
    );

    if (selectedSchedules.length > 0) {
      Swal.fire({
        title: "Apakah kamu yakin ingin menghapus jadwal yang dipilih?",
        text: "Tindakan ini tidak dapat dibatalkan.",
        icon: "warning",
        showCancelButton: true,
        confirmButtonColor: "#37a647",
        cancelButtonColor: "#d33",
        confirmButtonText: "Ya, hapus!",
        cancelButtonText: "Batal",
        allowOutsideClick: false,
      }).then((result) => {
        if (result.isConfirmed) {
          selectedSchedules.forEach((schedule) => {
            this.deleteSchedule(schedule.id);
          });

          Swal.fire({
            title: "Terhapus!",
            text: "Jadwal yang dipilih berhasil dihapus.",
            icon: "success",
          });
        }
      });
    } else {
      Swal.fire({
        title: "Tidak ada jadwal yang dipilih!",
        text: "Pilih setidaknya satu jadwal untuk dihapus.",
        icon: "info",
      });
    }
  }

  deleteSchedule(id) {
    this.deviceService.deleteDeviceScheduler(id).subscribe(() => {
      this.dataListScheduler(this.deviceId);
      this.hasSelected = false;
    });
  }
}
